==> servicecatalog-model-6.8.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassStatusFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceClassStatusFluent<A extends ClusterServiceClassStatusFluent<A>> extends BaseFluent<A>{
  public ClusterServiceClassStatusFluent() {
  }
  public ClusterServiceClassStatusFluent(ClusterServiceClassStatus instance) {
    instance = (instance != null ? instance : new ClusterServiceClassStatus());

    if (instance != null) {
      this.withRemovedFromBrokerCatalog(instance.getRemovedFromBrokerCatalog());
      this.withRemovedFromBrokerCatalog(instance.getRemovedFromBrokerCatalog());
    }
  }
  private Boolean removedFromBrokerCatalog;
  public Boolean getRemovedFromBrokerCatalog() {
    return this.removedFromBrokerCatalog;
  }
  public A withRemovedFromBrokerCatalog(Boolean removedFromBrokerCatalog) {
    this.removedFromBrokerCatalog=removedFromBrokerCatalog; return (A) this;
  }
  public boolean hasRemovedFromBrokerCatalog() {
    return this.removedFromBrokerCatalog != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceClassStatusFluent that = (ClusterServiceClassStatusFluent) o;
    if (!java.util.Objects.equals(removedFromBrokerCatalog, that.removedFromBrokerCatalog)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(removedFromBrokerCatalog,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (removedFromBrokerCatalog != null) { sb.append("removedFromBrokerCatalog:"); sb.append(removedFromBrokerCatalog); }
    sb.append("}");
    return sb.toString();
  }
  public A withRemovedFromBrokerCatalog() {
    return withRemovedFromBrokerCatalog(true);
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassStatusFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterServiceClassStatusFluent<A extends ClusterServiceClassStatusFluent<A>> extends BaseFluent<A>{
  public ClusterServiceClassStatusFluent() {
  }
  
  public ClusterServiceClassStatusFluent(ClusterServiceClassStatus instance) {
    this.copyInstance(instance);
  }
  private Boolean removedFromBrokerCatalog;
  
  protected void copyInstance(ClusterServiceClassStatus instance) {
    instance = (instance != null ? instance : new ClusterServiceClassStatus());
  
    if (instance != null) {
        this.withRemovedFromBrokerCatalog(instance.getRemovedFromBrokerCatalog());
        this.withRemovedFromBrokerCatalog(instance.getRemovedFromBrokerCatalog());
      }
  }
  
  public Boolean getRemovedFromBrokerCatalog() {
    return this.removedFromBrokerCatalog;
  }
  
  public A withRemovedFromBrokerCatalog(Boolean removedFromBrokerCatalog) {
    this.removedFromBrokerCatalog=removedFromBrokerCatalog; return (A) this;
  }
  
  public boolean hasRemovedFromBrokerCatalog() {
    return this.removedFromBrokerCatalog != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceClassStatusFluent that = (ClusterServiceClassStatusFluent) o;
    if (!java.util.Objects.equals(removedFromBrokerCatalog, that.removedFromBrokerCatalog)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(removedFromBrokerCatalog,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (removedFromBrokerCatalog != null) { sb.append("removedFromBrokerCatalog:"); sb.append(removedFromBrokerCatalog); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRemovedFromBrokerCatalog() {
    return withRemovedFromBrokerCatalog(true);
  }
  

}
